package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`"``!````<!8``#0````\!@$`!Q``<#0`(``+
M`"@`'P`>``8````T````-````#0```!@`0``8`$```0````$`````P```)0!
M``"4`0``E`$```T````-````!`````$````#``!PJ`$``*@!``"H`0``&```
M`!@````$````"````````'#``0``P`$``,`!```8````&`````0````$````
M`0```````````````````*2:``"DF@``!0```````0`!````^/\``/C_`0#X
M_P$`L`$``-@!```&```````!``(````<`@``'`(``!P"```P`0``,`$```0`
M```$````!````-@!``#8`0``V`$``$0```!$````!`````0```!1Y71D````
M```````````````````````'````$````%+E=&3X_P``^/\!`/C_`0`(````
M"`````0````!``````````````````````````````````````````0````O
M;&EB+VQD+G-O+C$`````````````(`(!`0`%`````````````````````/8`
M`+(`````````````````````,(`"``0````4`````P```$=.50`U^Z&QZU?U
M0L0*_F>\NFY=[3#YL`0````0`````0```$=.50```````P````(`````````
M`0```"X#```!````/@,```$```!(`P``#````%03```-````L%D``!D```#X
M_P$`&P````0````:````_/\!`!P````$````!````$P#```%````Y`P```8`
M``!T!@``"@```-$$```+````$````#4``'"D_0$`%0`````````#````0``"
M`!$````D$P``$@```#`````3````"`````$``'`!````!0``<`(````&``!P
M``````H``'`4````$0``<&<````2``!P'@```!,``'`C````'@```!@```#[
M__]O`0``"/[__V^$$@``____;P(```#P__]OMA$`````````````````````
M`````````````````````````````````````````````&$```!G````````
M```````1````*P``````````````80``````````````%@```"X`````````
M(P```&4````8`````````#H````B````!````$H````=````"0```&0````_
M``````````````!!````)0```"8```````````````<````D````$```````
M````````(0```$<```!B````8`````````!/`````````%,````@````'```
M`#,`````````10```!,````R````6P```#$``````````````!(````U````
M+````"<`````````````````````````*0`````````#``````````````!0
M````5P`````````Y````0@```#<```````````````````!2````+P```!L`
M```?````,````#8`````````+0```!<````````````````````5````````
M`"@````(````*@```$P```!#````9@``````````````````````````````
M````````````````````````````````"@``````````````50```%0````.
M``````````````````````````````````````````\````^`````````$``
M```:`````````#T````T``````````8``````````````!X````9````6```
M`#@`````````30``````````````7````%X`````````#0```!0`````````
M`````#L`````````70```$@````\````8P```$8``````````````$X`````
M````1````%D```````````````L```!)````#````````````````@``````
M``!+````7P``````````````40`````````````````````````%````````
M``````!6````6@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````%03`````````P`-`#`$``````(``````"``%0#7`P``J`$"````
M```0`!D`W0,``-`C```8````$@`.`.X#``#`)@``4````!(`#@`!`````0``
M```````3`/'_4`,``#`Y``#P`@``$@`.`/L#``!P+@``D````!(`#@!F`P``
MQ"(```P!```2``X`M0,``!`G``!@`0``$@`.``D$``"\4P``+`(``!(`#@`3
M!````"\``$@````2``X`RP,``"`\```\`0``$@`.`.("``#@60``!````!$`
M$0`N!``````"```````0`!4`9@``````````````%@```#L$``#`40``_`$`
M`!(`#@!&!```C"(``#@````2``X`3@0``'`6````````$@`.`%8$``````(`
M`````!``%0!=!```J`$"```````0`!D``0,`````````````(0```&D$``"0
M$P```````!``#@!P!```$%$``+`````2``X`>00``-`!`@``````$``9`!(`
M```P``(``````!$`%@```P`````````````1````J`,``,@P``!H"```$@`.
M`'X$``"H`0(``````!``&`!\`P``2"\``(`!```2``X`C@,``.@C``#8`@``
M$@`.`,$#```@``(`!````!$`%0";`P``<"@````&```2``X`YP$``)`3``#8
M`@``$@`.`+@!``"060```````!(```#*`@``@%D````````2````V@$``'!9
M````````$@```*L"``!@60```````!(```"W````4%D````````2````Q@``
M`$!9````````$@```-$``````````````!$````I`@``,%D````````2````
M^@$``"!9````````$@```)T"```060```````!(```!0`@```%D````````2
M````W@```/!8````````$@```/$```#@6````````!(```"]`0``T%@`````
M```2````0`(``,!8````````$@```'$"``"P6````````!(````P`@``H%@`
M```````2````U`$``)!8````````$@```!@"``"`6````````!(````&`0``
M<%@````````2````$@$``&!8````````$@```.H```!06````````!(```#L
M`0``0%@````````2````J0```#!8````````$@```#<"```@6````````!(`
M```"`P`````````````1````O`(``!!8````````$@```!P#````````````
M`!$````I`0```%@````````2````)00``/!7````````$@````H"``#@5P``
M`````!(```##`@``T%<````````2````$0(``,!7````````$@```/$"````
M`````````!$```#%`0`````````````B````L@(``+!7````````$@```)H`
M``"@5P```````!(````X`0``D%<````````2````B0``````````````$@``
M`'D``````````````!(```!8````@%<````````2````@0(``'!7````````
M$@```'("``!@5P```````!(```!)`0`````````````@````CP(``%!7````
M````$@```"$```!`5P```````!(```!-````,%<````````2````8P$`````
M````````(````%X"```@5P```````!(````"`@``$%<````````2````?P$`
M``!7````````$@```$D"``#P5@```````!(```"-`0``X%8````````2````
M1````-!6````````$@```'D"``#`5@```````!(````*`P``L%8````````2
M````\P$``*!6````````$@```/@"``"05@```````!(```"=`0``````````
M```B````,0``````````````$@```&,"``"`5@```````!(````F````<%8`
M```````2````K`$``&!6````````$@```*0"``!05@```````!(````<````
M0%8````````2````B0(``#!6````````$@```)8"```@5@```````!(```#1
M`@``$%8````````2`````%]$64Y!34E#7TQ)3DM)3D<`7U]23$1?34%0`'!E
M<FQ?9G)E90!P97)L7W!A<G-E`%!E<FQ?871F;W)K7W5N;&]C:P!P97)L7W)U
M;@!P97)L7V%L;&]C`%!E<FQ?<WES7W1E<FT`4$Q?8W5R<F5N=%]C;VYT97AT
M`&)O;W1?1'EN84QO861E<@!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R
M=6-T`'!E<FQ?9&5S=')U8W0`4&5R;%]S>7-?:6YI=#,`4&5R;%]N97=84P!0
M3%]D;U]U;F1U;7``4&5R;%]S869E<WES;6%L;&]C`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`%!E<FQ?;6=?<V5T`%!E<FQ?8W)O86M?;65M;W)Y7W=R87``4&5R
M;%]S=E]S971P=FX`4&5R;%]N97=84U]F;&%G<P!?251-7W)E9VES=&5R5$U#
M;&]N951A8FQE`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!?7V=M;VY?<W1A<G1?7P!097)L7V=E
M=%]S=@!E>&ET`&UE;6UO=F4`7U]C>&%?9FEN86QI>F4`<FUD:7(`7U]L:6)C
M7W-T87)T7VUA:6X`<W1R<W1R`'-T<F-H<@!S=')N8VUP`'-T<G)C:'(`=6YL
M:6YK`&UE;6-P>0!?7W-T86-K7V-H:U]F86EL`&]P96XV-`!S=')T;VL`8VQO
M<V5D:7(`<F5A9&QI;FL`;65M<V5T`%]?<W!R:6YT9E]C:&L`<F5A9`!?7V9P
M<FEN=&9?8VAK`&QS=&%T-C0`;'-E96LV-`!O<&5N9&ER`&UK9&ER`&%C8V5S
M<P!G971P:60`;65M8VAR`&UE;6-M<`!S=')D=7``<F5A9&1I<C8T`&=E='5I
M9`!S=')L96X`<W1R8VUP`%]?97)R;F]?;&]C871I;VX`7TE/7W-T9&EN7W5S
M960`<W1D97)R`')E86QL;V,`7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K
M`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\N-2XS-@!L:6)C+G-O+C8`
M;&0N<V\N,0!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V-U<G)E;G1?97AE
M8U]P<F]C`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!P87)?:6YI
M=%]E;G8`<&%R7VUK=&UP9&ER`'!A<E]D:7)N86UE`&UY7W!A<E]P;`!P87)?
M8VQE86YU<`!?9F)S<P!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!P
M87)?96YV7V-L96%N`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!?7V1A=&%?<W1A<G0`<VAA7W5P9&%T90!X<U]I;FET`%]?<W1A<G0`
M7V9D871A`%]?8G-S7W-T87)T`%]F=&5X=`!S:&%?:6YI=`!?96YD`%]E9&%T
M80!'3$E"0U\R+C0`1TQ)0D-?,BXS-`!'3$E"0U\R+C,S`$=,24)#7S(N,@!'
M3$E"0U\R+C,N,@!'3$E"0U\R+C,N-`!'3$E"0U\R+C`````````!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``@`!``$``0`!``(`
M`0`!``$``0`!``$``0`"``(`"0`"``$``0`!``4``@`"``,``0`!``(``@`&
M``(``@`(``$``0`"``(``0`"``(``@`'``$``@`"``(``@`"``4`!0`!``$`
M`0`!``$``@`&``$``@`"``$``0`"``(``0`"``$``0`%``0``@`"``$``0`#
M``$``0`"``$``@`"``(``0`!`$@#```0````(````!1I:0T```<`A00`````
M```!``<`/@,``!``````````M)&6!@``"0"/!```$````!1I:0T```@`A00`
M`!````"SD98&```&`)H$```0````$FEI#0``!0"E!```$````'(9:0D```0`
MKP0``!````!T&6D)```#`+L$```0````$&EI#0```@#'!```````````````
M````^/\!``,```#\_P$``P```"```@`#````I`$"``,```"@`0(`+Q````(`
M'#S<;)PG(>"9`^#_O2<0`+RO'`"_KTB!@H\$`$`0`````$B!F8\)^"`#````
M`!P`OX\(`.`#(`"])P(`'#R@;)PG(>"9`[#_O2=P@)F/-`"PKQ@`O*],`+^O
M2`"UKT0`M*]``+.O/`"RKS@`L:_,@)"/)`"EKR0`I2<@`*:O(`"F)U``I*]0
M`*0G```"CBP`HJ\)^"`#`````!@`O(],@8:/1("9C_B`A(][$!$$)2C``!@`
MO(]X@(*/``!"D%X`0!!P@8*/.^@#?%``L8\A$$,`!``D)@``18P`0`(\`P`Q
M)BL0@@!F`Z.0`P!C-'T`0!!F`Z.@C("9CPGX(`.`(`0`)`"ECR4X0``8`+R/
M4`"FCP``HHQ(@(./(("(CP``XJP<@(*/``!DC`(`PRC(`0>M!%U")`@`Y*P$
M`.*L'(""CPA=0B1J`&`4#`#BK(`0!@`$`*,D$`#D)"$0H@```&6,!`!C)`0`
MA"3\_T,4_/^%K`,`QB0@@)*/@#`&`!R`A8\A$.8`5(&9CQ``H*\E,"`"S`%$
MC@@BI20)^"`#``!`K!@`O(\V`$`0)8A``+R`F8\H`+0G"?@@`\P!1(XE*(`"
M&`"\CQR`DX\<@(2/X!=S)B7(8`*L`!$$J%J$)"X`0!`8`+R/8(&9CPGX(`/,
M`42.&`"\CP"!F8\)^"`#`````"P`HX\```*./@!B%!@`O(],`+^/)1`@`D@`
MM8]$`+2/0`"SCSP`LH\X`+&/-`"PCP@`X`-0`+TG&(&9CPGX(`,`````&`"\
MCR4@0``@@(*/*0"`$,P!1*SP@)F/"?@@`P`````[Z`-\&`"\CW"!@H\A($,`
M``"#C)+_`!`;!V"@-(&9CPGX(`/,`42.&`"\C\;_`!`EB$``(("5C\0!I(X%
M`(`03("9CX<)$00`````S/\`$!@`O(\<@(2/)2B``B7(8`)P`!$$1%J$)!@`
MO(\E($``P_]`$,0!HJ[R_P`03("9C["`F8\)^"`#`````*#_`!`$``8D8("9
MCPGX(`,!``0DJ("9CPGX(`,````````````````E`.`#`0`1!``````"`!P\
MM&F<)R'@GP,E^```&("$CP``I8\$`*8G^/\!)"3HH0/@_[TG)3@``!``H*\4
M`**O&`"]KVB`F8\)^"`#`````/__`!`````````````````"`!P\8&F<)R'@
MF0,@@(2/4(""CS0`A"0%`$00'(&9CP,`(!,`````"``@`P`````(`.`#````
M``(`'#PH:9PG(>"9`R"`A(]0@(6/-`"$)",HI`"#$`4`PB\%`"$HH@!#*`4`
M!0"@$`R!F8\#`"`3``````@`(`,`````"`#@`P`````"`!P\W&B<)R'@F0/@
M_[TG&`"PKR"`D(\0`+RO'`"_K[`!`I(-`$`4Z(""CP4`0!!4@(*/Z("9CPGX
M(`,``$2,$`"\CQR`F8_0%CDGR_\1!``````!``(DL`$"HAP`OX\8`+"/"`#@
M`R``O2<"`!P\<&B<)R'@F0,<@)F/"!<Y)\S_`!````````````(`'#Q0:)PG
M(>"9`\C_O2<0`+RO-`"_KS``MJ\L`+6O*`"TKR0`LZ\@`+*O'`"QKST`@!`8
M`+"OQ(""CP``5HPY`,`2/0`#)```@H`EH(``)9B@`$``0!`ED(``!`!#$```
M```!`$*"_/]`%`$`4B8CD%0"``#0CA```!(]`!4D)8C``H"`F8\E(``")3!`
M`@GX(`,E*(`"(1@2`@0`0!00`+R/``!B@`\`51``````!``PCO/_`!8$`#$F
M-`"_CR40``(P`+:/+`"UCR@`M(\D`+./(`"RCQP`L8\8`+"/"`#@`S@`O2<C
MB#8"`0!2)H.($0`A@!("``!QKC0`OX\E$``",`"VCRP`M8\H`+2/)`"SCR``
MLH\<`+&/&`"PCP@`X`,X`+TG-`"_CR6````P`+:/+`"UCR40``(H`+2/)`"S
MCR``LH\<`+&/&`"PCP@`X`,X`+TGQO\`$"60```"`!P\\&:<)R'@F0,P_[TG
MG("9CQ@`I2?$`+"O$`"\K\@`L:\EB(``S`"_K\R`D(\```*.O`"BKPGX(`,`
M````#P!`%!``O(\P`*./`$`$)`#P8S`#`&00`*`$-`D`9!0`````$(&9CP(`
M!20)^"`#)2`@`A``O(\"```0`0!"+"40``"\`*2/```#C@4`@Q3,`+^/R`"Q
MC\0`L(\(`.`#T`"])ZB`F8\)^"`#``````(`'#Q`9IPG(>"9`R#_O2?0`+*O
M&`"\K]P`OZ_8`+2OU`"SK\P`L:_(`+"OS("2CP``0H[$`**O!`"`$```````
M`(*`#`!`%"6`@`#$`*./``!"CF8`8A3<`+^/V`"TC]0`LX_0`+*/S`"QC\@`
ML(\(`.`#X`"])P2!F8\)^"`#`````!@`O(_P_T`0)8A``.R`F8\)^"`#)2`@
M`CT`0!`8`+R/$P!#D-+_8R0$`&`4$P!3)`$`8Y+V_V`0[("9CQ,`0Y#2_V,D
M.P!@$-R`F8\)^"`#)2```B4@8`(8`+R/W("9CPGX(`,EH$``&`"\CR$@@@*T
M@)F/"?@@`P(`A"3__P8D&`"\CP$`!20E($``%`"SKQ``L*\EH$``'("'CXB`
MF8\)^"`#Y%GG)"``I2<8`+R/"(&9CPGX(`,E((`"__\#)`8`0Q`8`+R/.`"B
MCP!``R0`\$(P(`!#$!R`F8_8@)F/"?@@`R4@@`(8`+R/%(&9CPGX(`,E((`"
M&`"\C^R`F8\)^"`#)2`@`L7_0!08`+R/P("9CPGX(`,E("`"&`"\CZ2`F8\)
M^"`#)2```J;_`!`8`+R/`0!CDM+_8R3#_V`4``````(`8I*P_T`0`````+[_
M`!``````\!DY)X?_$00E((`"X?\`$!@`O(^H@)F/"?@@`P`````"`!P\1&2<
M)R'@F0,0@+TG.(&9CVB``S0"``(DY'^VKR4P``#<?[2O)3@``-!_L:\EH(``
M['^_K^A_MZ_@?[6OV'^SK]1_LJ_,?["O(^BC`\R`EH\!``,\&`"\KRP`8S00
M`**O(1A]````PHX``&*L"?@@`P`````E(&``&`"\CP$`0RPC((,``(`#//__
M0B0D&(,`!P!A!/__43#__S$F__\#/"48(P(!`'$D*Q@C`O__8R0CB%$`(R"#
M`"L040`CF((`5@!@!O__`B3^_Q<\(("2CP$``CST__<V,`!"-"$05P`!`!4\
M(;A=``@`M280`%(F.(&9CR4P(`(E((`"$`"@KPGX(`,E.&`")3"@`A@`O(\E
M*.`"((&9CPGX(`,E((`""`!#+#(`8!08`+R/^/]")"&`X@(K$!<"!P!`$%R!
MF8\L```0__\"//__$"8K$!<")P!`%%R!F8\(``8D)2A``@GX(`,E(``"]_]`
M%!@`O(_^_P(\`0`#//3_0C0P`&,T(1AB`"$0?0`C@`("PQ\0`"$0$0(A&',`
M*X!0`"&``P(!``,\+`!C-"$8?0```&2,``##CAL`@Q1H@`@T)1@``B'HJ`/L
M?[^/Z'^WC^1_MH_@?[6/W'^TC]A_LX_4?[*/T'^QC\Q_L(\(`.`#\'^])___
M`CS__W,F(1@B`O__!20K('$`(9B3`+G_8A0EB&``N/]E%CB!F8___P(DX/\`
M$/__$"2H@)F/"?@@`P`````"`!P\$&*<)R'@F0/([[TGF("9C_\/!B0D$+&O
M$`"\KS`0M*\EH(``+!"SKQP`LR<H$+*O)9"@`#00OZ\E*&`"(!"PK\R`D8\<
M@(2/```BCNQ9A"0<$**O"?@@`P`````)`$`8$`"\CR6`0``?$`,F(1A]`/SO
M8X`8`&`4__]")!4`0!0`````<(&"CSOH`WPH@9F/)3!``B4H@`(A$$,`"?@@
M`P``1(P0`+R/'!"CCP``(HX;`&(4-!"_CS`0M(\L$+./*!"RCR00L8\@$+"/
M"`#@`S@0O2<E@$``A("9CR\`!20E,``""?@@`R4@8`+E_T`0$`"\CW"!@H\[
MZ`-\T("9CR4X``(E,&`"(1!#`"4H@`()^"`#``!$C./_`!`0`+R/J("9CPGX
M(`,``````@`</.!@G"<AX)D#N/^])ST``B0H`+&O,`"SKR68@``D`+"O)8"@
M`!``O*]$`+^O0`"WKSP`MJ\X`+6O-`"TKRP`LJ_,@)&/``"C@```)8X<`*6O
M`@!B%-R`F8\!`!`F"?@@`R4@``(8`*4G$`"\CR4@8`(<@)F/X!<Y)P3^$00E
MH$``$`"\CU0`0!`ED$``W("9CPGX(`,E($``*Q!4`$``0!`0`+R/&`"UC\2`
MEH^`J!4```!E@CT``B0&`*`4)1A@`G0``!`E&````0!E@`,`H!`!`&,D_/^B
M%``````C&',```#2C@(`A":T@)F/(2"#``GX(`,AD%4"$`"\CQH`0!```$*N
M``##C@$`928``&*"/0`')"$8=0```&2,!P!`%```@J`(```0)1B`````HH`!
M`*4D)@!`$`$`8J`E&(``^O]'%`$`A"0]``0D`0!B)```9*````."`0!")`$`
M$";\_V`4__]#H!P`HX\``"*.30!B%$0`OX]``+>//`"VCS@`M8\T`+2/,`"S
MCRP`LH\H`+&/)`"PCP@`X`-(`+TG```"@@$`4B8!`!`F[O]`$/__0J(```*"
M`0!2)@$`$";W_T`4__]"HN?_`!``````W?\`$"48@`#$@):/``#7C@``XHXM
M`$`0)1#@`B60```$`$.,)2!``@0`0B3\_V`4`0!2)@,`A"2`(`0`((""C\`!
M0XP6`&`41(&9C[2`F8\!``,D"?@@`\`!0ZP0`+R/S?]`$"4@0`"4@)F/@*@2
M`"4HX`()^"`#)3"@`A``O(\E($````#"K@$`0B88`+*O@!`"`"$@@@"1_P`0
M``"`K"4H@``)^"`#)2#@`A``O(\E($``N/]`$```PJ[R_P`0@*@2`)/_`!``
M`-*."``$)-K_`!`ED```J("9CPGX(`,``````@`</"A>G"<AX)D#V/^])R2`
MAX\[Z`-\'("%CW2`F8\@`+"OB)KG)'"!D(_\6:4D_("&CR0`OZ\A@`,"&`"\
MKPGX(`,```2.&`"\CP``!(X4`*"O'("'CQR`A8_T@)F/`%WG)"B`AH\86J4D
M"?@@`Q``IZ\D`+^/(`"PCP@`X`,H`+TG`@`</*1=G"<AX)D#<(&"CSOH`WPD
M@(>/'("%CR$00P#\@(:/=("9CXB:YR3\6:4D"``@`P``1(P"`!P\;%V<)R'@
MF0/`W[TG:(&9CS0@L:\\(+^O&`"\KS@@LJ\H$+(G,""PKR0`L"?,@)&/```B
MCBP@HJ\)^"`#``````$0!B08`+R/`0`%)!``HJ\E(``"'(""CQR`AX^(@)F/
M/%I")#!:YR0)^"`#%`"BKP`0!B08`+R/)2A``IB`F8\)^"`#)2```AT`0`08
M`+R/M("9CP$`1"0)^"`#)8!``!@`O(\6`$`0)2!``."`F8\E,``""?@@`R4H
M0`(A@%``&`"\CR4@0`````"B+""CCP``(HX'`&(4/""_CR40@``X(+*/-""Q
MCS`@L(\(`.`#0""])ZB`F8\)^"`#`````/+_`!`E(````@`</&!<G"<AX)D#
M+("9C[C_`!```````@`</$A<G"<AX)D#`.^])QR`F8_P$+:OX!<Y)R``O*_\
M$+^OX!"RKR60H`#<$+&O)8B``-@0L*\L`*4G^!"^K_00MZ_L$+6OZ!"TK^00
MLZ_,@):/'("$CP``PHY$6H0DU!"BK^3\$00`````+P`%)"``O(\E("`"0(&9
MCPGX(`,E@$``&`!`$"``O(\<@(2/)2@@`AR`F8]0'SDGLOX1!%!:A"0E$"`"
M(`"\C]00I(\``,..A0"#%/P0OX_X$+Z/]!"WC_`0MH_L$+6/Z!"TC^00LX_@
M$+*/W!"QC]@0L(\(`.`#`!&])VR`F8\E($`"'("2CPGX(`,`````(`"\CV!:
M12:@@)F/"?@@`R4@0``@`+R/W?]`$"6X0``<@)6/U`"S)QR`E(\``.*";%JU
M)D8`0!!D6I0F!@``$F2`F8\E*.`""?@@`R4@``(U`$`0(`"\C]R`F8\)^"`#
M)2#@`B\`!"3__T,D)?!``"$8XP(K$.,"!P!`%"``O(\-```0W("9CP``8*#_
M_V,D!`#C$@```````&*`^O]$$-R`F8\)^"`#)2#@`B``O(\E\$``W("9CPGX
M(`,E("`"(1!>``$`0B0`$$(LL/]`$"``O(^(@)F/`!`&)`$`!208`+&O)2!@
M`A0`M:\E.(`""?@@`Q``MZ\P`*4G(`"\CPB!F8\)^"`#)2!@`@8`0!0@`+R/
M2`"BCP"``S0`\$(P&@!#$!"!F8^@@)F/8%I%)@GX(`,E(```(`"\CY3_0!`E
MN$````#B@KS_0!0`````!0``$@````````*2TO]")`4`0!``````'("7CP$`
M'B30_P`00%KW)@$``I+K_T`0H("9C_G_`!`<@)>/`0`%)`GX(`,E(&`"X_]`
M%"``O(\<@(2/)2A@`AR`F8]0'SDG+OX1!%!:A"0@`+R/;("9CPGX(`,E(&`"
M>?\`$"``O(^H@)F/"?@@`P`````"`!P\<%F<)R'@F0/@_[TG)(&9CR\`!200
M`+RO&`"PKQP`OZ\)^"`#)8"```(`0!`0`+R/`0!0)!P`OX\E(``";("9CQ@`
ML(\(`"`#(`"])P(`'#P@69PG(>"9`\COO2<P$+.O$`"\KS00OZ\L$+*O*!"Q
MKR00L*_,@)./``!BCAP0HJ\V`(`0````````@H`S`$`0)9"``-R`F8\)^"`#
M``````$`1B0E@$```1#"+#H`0!`0`+R/X("9CQP`L2<E*$`""?@@`R4@(`+_
M_P(F$`"\CR$0(@(K&"("!P!@%"\`!"0(```0)(&9CP``0*#__T(D!0!1$"\`
M!20``$.`^O]D$"2!F8\O``4D"?@@`R4@(`(2`$`0$`"\CRL8(@(<`&`4````
M`&R`F8\)^"`#)2`@`A``O(\<$*2/``!CCA@`@Q0T$+^/,!"SCRP0LH\H$+&/
M)!"PCP@`X`,X$+TG'!"CCP``8HX.`&(4'("$CS00OX\P$+./+!"RCT!:A"0H
M$+&/)!"PCVR`F8\(`"`#.!"])^3_`!```$"@YO\`$"40``"H@)F/"?@@`P``
M```"`!P\P%><)R'@F0.X_[TG-`"UKRP`LZ\H`+*O)`"QKQ@`L2<@`+"O$`"\
MKT0`OZ]``+ZO/`"WKS@`MJ\P`+2OS("5CQR`DH\<@)"/Q("3CP``HHYP6E(F
MX!<0)AP`HJ\E*"`")<@``L'[$00E($`"$@!`$!``O(\8`*./``!BCH`8`P`A
M$$,`!`!#C/3_8!```$.L"`!#C`0`0B3]_V`4``!#K"4H(`(ER``"L/L1!"4@
M0`+P_T`4$`"\CQR`DH_$@)./?%I2)B4H(`(ER``"I_L1!"4@0`(2`$`0$`"\
MCQ@`HX\``&*.@!@#`"$00P`$`$.,]/]@$```0ZP(`$.,!`!")/W_8!0``$.L
M)2@@`B7(``*6^Q$$)2!``O#_0!00`+R/'("2C\2`DX^$6E(F)2@@`B7(``*-
M^Q$$)2!``A(`0!`0`+R/&`"CCP``8HZ`&`,`(1!#``0`0XST_V`0``!#K`@`
M0XP$`$(D_?]@%```0ZPE*"`")<@``GS[$00E($`"\/]`%!``O(\<@)*/Q("3
MCY!:4B8E*"`")<@``G/[$00E($`"$@!`$!``O(\8`*./``!BCH`8`P`A$$,`
M!`!#C/3_8!```$.L"`!#C`0`0B3]_V`4``!#K"4H(`(ER``"8OL1!"4@0`+P
M_T`4$`"\CQR`E(_$@)./F%J2)B4H(`(ER``"6?L1!"4@0`(2`$`0$`"\CQ@`
MHX\``&*.@!@#`"$00P`$`$.,]/]@$```0ZP(`$.,!`!")/W_8!0``$.L)2@@
M`B7(``)(^Q$$)2!``O#_0!00`+R/'("2C\2`DX^H6E(F)2@@`B7(``(_^Q$$
M)2!``A(`0!`0`+R/&`"CCP``8HZ`&`,`(1!#``0`0XST_V`0``!#K`@`0XP$
M`$(D_?]@%```0ZPE*"`")<@``B[[$00E($`"\/]`%!``O(\<@):/Q("3CT1:
MTB8E*"`")<@``B7[$00E($`"$@!`$!``O(\8`*./``!BCH`8`P`A$$,`!`!#
MC/3_8!```$.L"`!#C`0`0B3]_V`4``!#K"4H(`(ER``"%/L1!"4@0`+P_T`4
M$`"\CQR`GH_$@)./M%K2)R4H(`(ER``""_L1!"4@0`(2`$`0$`"\CQ@`HX\`
M`&*.@!@#`"$00P`$`$.,]/]@$```0ZP(`$.,!`!")/W_8!0``$.L)2@@`B7(
M``+Z^A$$)2!``O#_0!00`+R/'("7C\2`DX_`6O(F)2@@`B7(``+Q^A$$)2!`
M`A(`0!`0`+R/&`"CCP``8HZ`&`,`(1!#``0`0XST_V`0``!#K`@`0XP$`$(D
M_?]@%```0ZPE*"`")<@``N#Z$00E($`"\/]`%!``O(\<@)*/Q("3C\Q:4B8E
M*"`")<@``M?Z$00E($`"$@!`$!``O(\8`*./``!BCH`8`P`A$$,`!`!#C/3_
M8!```$.L"`!#C`0`0B3]_V`4``!#K"4H(`(ER``"QOH1!"4@0`+P_T`4$`"\
MCQR`DH_$@)./4%I2)B4H(`(ER``"O?H1!"4@0`(2`$`0$`"\CQ@`HX\``&*.
M@!@#`"$00P`$`$.,]/]@$```0ZP(`$.,!`!")/W_8!0``$.L)2@@`B7(``*L
M^A$$)2!``O#_0!00`+R/'("$CR4H(`(ER``"I?H1!-A:A"00`+R/!@!`$"4H
M0``<@)F/4!\Y)WK\$03`6N0F$`"\CQR`A(\E*"`")<@``ICZ$03L6H0D$`"\
MCP<`0!`E*$``'("$CQR`F8]0'SDG;/P1!`!;A"00`+R/'("$CR4H(`(ER``"
MBOH1!`Q;A"00`+R/&@!`$"4H0``<@)F/4!\Y)U_\$01$6L0F$`"\CQP`HX\`
M`**.'P!B%!R`A8^86H0F'("9CT0`OX]``+Z/,%NE)#P`MX]0'SDG.`"VCS0`
MM8\P`+2/+`"SCR@`LH\D`+&/(`"PCTK\`!!(`+TG'("$CR4H(`(ER``":?H1
M!!Q;A"00`+R/Y?]`$"4H0``<@)F/4!\Y)S[\$02T6L0GW_\`$!``O(^H@)F/
M"?@@`P`````"`!P\P%&<)R'@F0/8_[TG'("$CQR`F8\8`*4G(`"PK[1:A"00
M`+ROX!<Y)R0`OZ_,@)"/```"CAP`HJ],^A$$``````T`0!`0`+R/``!"@`H`
M0!``````,`!"."L0`@`<`*2/```#C@8`@Q0D`+^/(`"PCP@`X`,H`+TG^/\`
M$"40``"H@)F/"?@@`P`````"`!P\,%&<)R'@F0/@_[TGR("9CQ``O*\<`+^O
M"?@@`P`````0`+R/U("9CPGX(`,E($```@!`$!P`OX\``$*,"`#@`R``O2<"
M`!P\Z%"<)R'@F0.X_[TG'("9CR@`I2<X`+*OX!<Y)R``O*\\`+.O-`"QKR6(
M@`!$`+^O0`"TKS``L*_,@)*/'("3CP``0HXT6V0F+`"BKQ'Z$00`````!0!`
M$"``O(\E@$````!"@!``0!2X@)F/+`"CCP``0HX^`&(4-%MD)B4H(`(<@)F/
M1`"_CT``M(\\`+./4!\Y)S@`LH\T`+&/,`"PC]C[`!!(`+TG)2@@`@GX(`,E
M(``"#`!`$"``O(\L`*./``!"CBH`8A1$`+^/0`"TCSP`LX\X`+*/-`"QCS``
ML(\(`.`#2`"])]R`F8\)^"`#)2`@`B4@``(@`+R/W("9CPGX(`,EH$``(`"\
MCR$@@@*T@)F/"?@@`P(`A"3__P8D(`"\CR6@0``!``4D&`"PKQ``L:\E((`"
M'(""CQR`AX^(@)F/8%I")&1:YR0)^"`#%`"BKRP`HX\``$*.!`!B%"``O(\T
M6V0FQ?\`$"4H@`*H@)F/"?@@`P`````"`!P\:$^<)R'@F0.0_KTG'(""CV0!
MMZ\EN(``,`"BKT1:1"0<@(*/:`&^KU@!M*],6T(D*`"\KUP!M:\\`+4G0`"B
MKQR`@H\E**`"S(">CQR`E(]`6D(D;`&_KV`!MJ]$`**OX!>4)AR`@H]4`;.O
M)<B``E`!LJ\$6T(D3`&QKT@!L*]<`**O'(""CP``PX](`*"O5%M")&P`H*]$
M`:.O8`"BKQR`@H]4`*"O2%I")&0`HJ\<@(*/7%M")&@`HJ\<@(*/8%M")$P`
MHJ\<@(*/:%M"))#Y$010`**O!0!`$"@`O(\E@$````!"@&L!0!0P@)F/R("9
MCPGX(`,`````*`"\C]2`F8\)^"`#)2!``*P`0!`H`+R/``!2C*H`0!),`*2/
MW("9CPGX(`,E($`"*`"\CT`@`@"T@)F/"?@@`P$`A"0``$.")9A``"@`O(\0
M`&`0)8!``!R`D8]T6S$FB("9CP$`4B;_`&,P__\&)!``HZ\!``4D)2!@`@GX
M(`,E."`"`@!S)@``0X+T_V`4*`"\CQR`A(]8`+,G'("2CP!;A"0$```00!E2
M)@0`9(X4`(`0!`!S)B7(@`)6^1$$)2B@`B@`O(_X_T`0)8A`````0H#U_T`0
M)<A``J;Y$00E("`"\?]`$"@`O(]L@)F/"?@@`R4@(`(H`+R/$0!`%"6P0``<
M@)*/0`"Q)T`94B8``#:.#`#`$MR`F8\``,*"9@!`$"7(0`*3^1$$)2#``ED`
M0!0H`+R/!``VCO?_P!8$`#$FW("9CPGX(`,E(,`")2```B@`O(_<@)F/"?@@
M`R6(0``H`+R/(8@B`@0$,2:T@)F/"?@@`R4@(`+__P8D*`"\CR600``!``4D
M'`"PKR4@0`(0`+:O'("3CQR`@H\<@(>/B("9CVQ:<R:(6T(D?%OG)!0`LZ\)
M^"`#&`"BK\`!!20H`+R/9(&9CPGX(`,E($`"__\#)`@`0Q0H`+R/;(&9CPGX
M(`,`````$0`#)```0HS=`$,4*`"\CYR`F8]P`*4G"?@@`R4@0`(H`+R/!@!`
M%"6`0`"(`**/`$`#)`#P0C!(`$,0R("9C^2`@H\!``4D'("&CU"!F8\``.>.
M``!$C,Q;QB0)^"`#$`"RKR@`O(\EB```1`&CCP``PH\^`6(4;`&_CR40(`)H
M`;Z/9`&WCV`!MH]<`;6/6`&TCU0!LX]0`;*/3`&QCT@!L(\(`.`#<`&])VR`
MF8\E(,`""?@@`P0`,28H`+R/F/]`$"6P0`"D_P`0W("9CZ'_`!`EL```3`"D
MCPX`@!!,`+`G)<B``M#X$00E**`"*`"\CP0`0!`E($````!"@`\`0!1L@)F/
M!``0)@``!([U_X`4)<B``K2`F8\)^"`##0`$)%,``R0H`+R/)9A``"6`0``<
M@)*/3/\`$$1;4B8)^"`#`````"@`O(\Z_T`4)9!``.W_`!`$`!`F"?@@`Y``
MMH^V_\(6*`"\CX@`HH_``0,D_P%",++_0Q3D@(*/M("9CPGX(`,E("`")2B@
M`B@`O(\ER(`")8A``!R`A(^B^!$$(%R$)"@`O(^4`$`0)2A``#2`F8^>^Q$$
M``#DCB@`O(^.`$`0);!``-R`F8\)^"`#)2#``B480``$`$(L$@!`%"@`O(\<
M@(6/_/]D)&2`F8\A(,0"-`"CKPGX(`,H7*4D"0!`%"@`O(\T`*./!``"),4`
M8A`A&,,"+P`")/O_8X#!`&(0`````"4HH`(<@)6/)<B``GSX$02T6J0F<0!`
M$"@`O(\``$*`;@!`$#```R1M`$,0?("9CQR`@H^T6J0F'("%C___%B01`!<D
M4!]9)#!;I21(^A$$-`"YKR@`O(]H@9F/"?@@`P````#__P8D*`"\CP$`!20E
M("`"&`"BKQ0`LZ\0`+*O'("4CQR`AX^(@)F/`%V4)DA<YR0)^"`#'`"TKR@`
MO(\<@)6/%P``$%A<M29L@9F/"?@@`P```````$*,%P!7%"@`O(]H@9F/"?@@
M`P$`$";__P8D*`"\CP$`!20@`+2O)3B@`AP`L*\E("`"&`"BKQ0`LZ^(@)F/
M"?@@`Q``LJ\H`+R/9(&9C\`!!20)^"`#)2`@`N7_5A`H`+R/%(&9CPGX(`,E
M($`")2@@`C``HH\T`+F/"?@@`T1:1"0H`+R/,("9CPC^$00E("`"//\`$"@`
MO(_D@(./`0`%)!R`AH]0@9F/``#GC@``9(R06\8D%`"BKPGX(`,0`+*O+_\`
M$"@`O(_X_1$$)2```D0!HX\``,*/:P!B%"@`O(]L`;^/)2```F@!OH]D`;>/
M8`&VCUP!M8]8`;2/5`&SCU`!LH],`;&/2`&PCVR`F8\(`"`#<`&])W+_`!``
M`/:.?("9CR4H```)^"`#)2#``B@`O(^/_T`0):!``!R`F8_L&SDG`OD1!"4@
M0``H`+R/B/]@!"6X0`#V_T8D.(&9C___=B00`*"O*SC"`"$X]@`)^"`#)2"`
M`A`!I2<H`+R/!@`&)#0`I:\@@9F/"?@@`R4@@`)!0P(\$`&CCP!#0B0H`+R/
M<_]B%#0`I8\$`*.42$4")'#_8A0<@(*/SO_F)CB!F8\E((`"$`"@KRLXUP`A
M./8`"?@@`Q@!L"<H``8D*`"\CR4H``(@@9F/"?@@`R4@@`+__P8D*`"\CP$`
M!20E("`"&`"PKQ0`LZ\0`+*O'(""CQR`AX^(@)F/`%U")$`!H*,X7.<D"?@@
M`QP`HJ\H`+R/'(""CU`?0B2(_P`0-`"BKP0`]XX^_^`2W("9CPGX(`,E(.`"
M!`!#+#G_8!0H`+R/'("%C_S_0B1D@)F/(2#B`@GX(`,P7*4D"K#B`C#_`!`H
M`+R/J("9CPGX(`,``````@`</`!'G"<AX)D#P/^])QR`A(\[Z`-\)`"PKYA:
MA"1P@9"/$`"\KS0`M*\8`+0G(1`#`BP`LJ\H`+&O)2B``CP`OZ\X`+6O,`"S
MK\R`DH\``%.,'("1CP``0XYH`&*2X!<Q)AP`HZ\ER"`"D/<1!&D`8J(%`$`0
M$`"\CP``1(`Q``,D@P"#$``````X@)F/J_L1!``````[Z`-\(1`#`A``O(\`
M`%.,'("%CP,`!R0P@9F/`0`&)"4@8`()^"`#;%RE)!``O(\0`$`0)9A``!``
M0HP[Z`-\(:@#`AR`AH\H@9F/``!%C'!<QB0)^"`#``"DCA``8HX``$6,"`"B
MC(`%0GQR`$`4$`"\CSOH`WP<@(6/(:@#`C"!F8\#``<D`0`&)```I(X)^"`#
M>%RE)!``O(\/`$`0)9A``!R`A(\E*(`")<@@`EGW$0106H0D$`"\CU0`0!`E
M,$``$`!BCBB!F8\``*2."?@@`P``18P0`+R/.^@#?!R`A8\A@`,"6(&9CP$`
M!B0@@)6/?%RE)```$XX)^"`#)2!@`B4@8`(0`+R/)2A``!R`AH\H@9F/"?@@
M`Y1<QB0E*(`"$`"\CR7((`(```*.'("$CVD`0*`W]Q$$1%J$)!``O(\E@$``
M(`!`$,0!HJYD@9F/P`$%)`GX(`,E(``"`0!#)`(`8RP,`&`4$`"\CQ$``R0)
M`$,0)3A``""`@H\<@(2/)3```I"`F8_(`4*,P%R$)`GX(`,``$6,'`"CCP``
M0HXI`&(4/`"_CS@`M8\T`+2/,`"SCRP`LH\H`+&/)`"PCP@`X`-``+TG((""
MCSR`F8]*_1$$R`%$C!``O(\E@$``VO]`%,0!HJX<@(2/D("9CPGX(`.<7(0D
M`0!"@(/_0!`X@)F/>_\`$``````@@(*/$`!CCAR`F8_(`4*,``!DC"`>.2>+
M^!$$``!%C*K_`!`0`+R/K("9CPGX(`,``*2.B_\`$!``O(^H@)F/"?@@`P``
M```"`!P\$$2<)R'@F0/0_[TG0("9CR@`LJ\0`+RO+`"_KR0`L:\EB(``(`"P
MK\R`DH\``$*.'`"BKZWZ$00`````+P`%)!``O(\E($``)(&9CPGX(`,E@$``
M`@!`$!``O(\!`%`D;("9CPGX(`,E(``"&`"E)Q``O(\E@$``'("$CQR`F8_@
M%SDGS?81!+1:A"0+`$`0$`"\CP``0X`(`&`0,``")`8`8A``````!``@$@``
M`````"*""@!`%!R`A8\<`*./``!"CAD`8A0L`+^/*`"RCR0`L8\@`+"/"`#@
M`S``O2<$``8D@("9CR4@``()^"`#B%NE)/'_0!00`+R/'`"CCP``0HX)`&(4
M'("9CR4@(`(L`+^/*`"RCR0`L8_P&3DG(`"PCRGW`!`P`+TGJ("9CPGX(`,`
M``````````(`'#S00IPG(>"9`S#]O2?,@(*/)1B``#@`9R00`+RO>`!K),P"
MOZ__``H\R`*^K\0"MZ_``K:OO`*UK[@"M*^T`K.OL`*RKZP"L:^H`K"O'`"B
MKQ@`I*\@`*0G``!"C"4H@`"D`J*O!`#CC`@`YR00`*4D]/^@K/S_H*P"$@,`
M^/_FC`).`P``1@,``/]",*`P!GP`&@,`)1!)``(T)@`E$$@`)!AJ`/#_IJPE
M$$,`[?]G%?C_HJR(`+./``*>)(P`HX^0`+*/E`"QCY@`HH^<`+"/,`"YCS0`
MN(\X`*^//`"NCT``K8]$`*R/2`"KCTP`JH]0`*F/5`"HCU@`MX\#```07`"V
MCR6XX``EL,``0`"'C`@`A"0\`(:,):A``"6@``(E@```?`"`K/C_@HS\_X6,
M)A!'`"8HI@`F$%,`)ABC`"8060`F&'@`PB\"`$`8`P!`$`(`)1AE`"400P`E
MF$`">`""K"48(`(ER.`!)<#``25XH`$E<(`!)6A@`25@0`$E6"`!)5```260
MH`(EB(`")4C@`MO_GA0E0,`"&`"QCX):`CP@`*R/F7E")```)HXA8((!!``E
MC@@`*8X,`"2.PFX&`$!9!0`@`"J.@G`)`!``)XZ`)P0`&``HCB58;0$$`""N
M@&\)``P`(*XE((X`%``@KD`9!@`<`""N)6BD`2@`I(\A8(H!)1AK`"98Z`""
MP`8`(1AL`(`O!0`D6&D!(2""`(!W!@`F6&@!(1AK`"4HN``F6.T`)7#%`3``
MI8\D6&8!(2"(`,)^`P!`80,`)EAG`2$@BP`A**(`)5B/`29@K@$A((L`)&"#
M`8+(`P`A**<`@%\#`"88C0$X`*R/PL8$`$!Y!``A&*,`)5AY`24H^`$A8((!
M(1AE`"8HRP$A8(T!)&BD`(+(!`"`+P0`)B"N`4``K8_"Q@,`0'D#`"$@A`$E
M*+D`)6#X`2%HH@$A((P`)F!E`2%HK@$D<(,!@L@#`(!G`P`F&,L!(1BC`4@`
MK8_"Q@0`0'D$`"5@F0$E</@!(6BB`2$8;@`F<*P`(6BK`21PQ`&"R`0`@%\$
M`"8@Q0$A(*0!4`"MC\+&`P!`>0,`)5AY`25P^`$A:*(!(2".`"9PBP$A:*4!
M)'##`8+(`P"`+P,`)AC,`2$8HP%8`*V/PL8$`$!Y!``E*+D`)7#X`2%HH@$A
M&&X`)G!E`2%HK`$D<,0!@L@$`(!G!``F(,L!(2"D`6``K8_"Q@,`0'D#`"5@
MF0$E</@!(6BB`2$@C@`F<*P`(6BK`21PPP&"R`,`@%\#`"88Q0$A&*,!:`"M
MC\+&!`!`>00`)5AY`25P^`$A:*(!(1AN`"9PBP$A:*4!)'#$`8+(!`"`+P0`
M)B#,`2$@I`%P`*V/PL8#`$!Y`P`E*+D`)7#X`2%HH@$A((X`)G!E`2%HK`$D
M<,,!@L@#`(!G`P`F&,L!(1BC`7@`K8_"Q@0`0'D$`"5@F0$E</@!(6BB`2$8
M;@`F<*P`(6BK`21PQ`&"R`0`@%\$`"8@Q0$A(*0!@`"MC\+&`P!`>0,`)5AY
M`25P^`$A:*(!(2".`"9PBP$A:*4!)'##`8+(`P"`+P,`)AC,`2$8HP&(`*V/
MPL8$`$!Y!``E*+D`)7#X`2%HH@$A&&X`)G!E`2%HK`$D<,0!@L@$`(!G!``F
M(,L!(2"D`9``K8_"Q@,`0'D#`"5@F0$E</@!(6BB`2$@C@`F<*P`(6BK`21P
MPP&"R`,`@%\#`"88Q0$A&*,!F`"MC\+&!`!`>00`)5AY`25P^`$A:*(!(1AN
M`"9PBP$A:*4!)'#$`8+(!`"`+P0`)B#,`2$@I`&@`*V/PL8#`$!Y`P`E*+D`
M)7#X`2%HH@$A((X`)G!E`2%@K`$D:,,!@L@#`(!W`P`F&*L!J`"MC\+&!`!`
M>00`(1B#`25PV0$E8/@!(6BB`2$8;``F8*X`(6BK`218A`&"8`0`@"<$`"98
M90$A:*L!)5B,`+``K(_"Q@,`0'D#`"%@@@$E(/@!(6BD`28@RP$A8(4!)""#
M`((H`P"`'P,`)B".`"%@A`$E(&4`N`"EC\+&#0!`>0T`(2BB`"889`$A**X`
M)!AM`"40^`$F&&L`(6""`2$HHP#``*./V6X"/()X#0"AZT(T@&\-`"$88@`E
M:*\!(1AK`"98C0`F6&P!(1AK`,@`JX_"Q@P`0'$,`()X#`"`9PP`(5AB`25P
MV`$A**X`)6"/`2$@9`$F6*P!)EAE`<+&!0"">`4`0'$%`"$@BP"`7P4`T`"E
MCR5PV`$A&&X`(2BB`"58;P$A**T`)FB+`29HHP'"Q@,`@G@#`$!Q`P`A**T`
M@&\#`-@`HX\E<-@!(2".`"$88@`E:*\!(1AL`"9@;0$F8(0!PL8$`()X!`!`
M<00`(1AL`(!G!`#@`*2/)7#8`2$HK@`A(((`)6"/`2$@BP`F6*P!)EAE`<+&
M!0"">`4`0'$%`"$@BP"`7P4`Z`"ECR5PV`$A&&X`(2BB`"58;P$A**T`)FB+
M`29HHP'"Q@,`@G@#`$!Q`P`A**T`@&\#`/``HX\E<-@!(2".`"$88@`E:*\!
M(1AL`"9@;0$F8(0!PL8$`()X!`!`<00`(1AL`(!G!`#X`*2/)7#8`2$HK@`A
M(((`)6"/`2$@BP`F6*P!)EAE`<+&!0"">`4`0'$%`"$@BP"`7P4```&ECR5P
MV`$A&&X`(2BB`"58;P$A**T`)FB+`29HHP'"Q@,`@G@#`$!Q`P`A**T`@&\#
M``@!HX\E<-@!(2".`"$88@`E:*\!(1AL`"9@;0$F8(0!PL8$`()X!`!`<00`
M(1AL`(!G!``0`:2/)7#8`2$HK@`A(((`)6"/`2$@BP`F6*P!)EAE`<+&!0""
M>`4`0'$%`"$@BP"`7P4`&`&ECR5PV`$A&&X`(2BB`"58;P$A**T`)FB+`29H
MHP'"Q@,`@G@#`$!Q`P`A**T`@&\#`"`!HX\E<-@!(2".`"$88@`E:*\!(1AL
M`"9@;0'"Q@0`)F"$`4!Q!`"">`0`(1AL`(!G!``H`:2/)7#8`2$HK@`A(((`
M)6"/`<+&!0!`<04`(2"+`"98K`$E<-@!)EAE`2$8;@"">`4`(2"+`(!?!0`P
M`:6/PL8#`$!Q`P`A**(`)5AO`25PV`$A((X`(2BM`"9PBP$F<,,!@G@#`"$H
MK@"`=P,`.`&CC\+&!`!`:00`(1AB`"5PSP$E:+@!(2BM`"$8;``F:&X!)FBD
M`8)X!``A&&T`@&\$`$`!I(_"Q@4`0&$%`"$@@@`E:*\!)6"8`2$@BP`F6,T!
M(1AL`"9890$A((L`2`&KC\+&`P!`80,`@G@%`(`O!0`E8)@!(5AB`2$@C``E
M8*\`)BBL`2%8;@$F**,`(5AE`8+``P"`+P,`4`&CC\)^!`!`<00`(1AB`"5P
MSP$A>&X!)7"X`"98C@$A&&T`)EAD`2$8:P!8`:N/@F@$`(`G!`#"Q@\`0"D/
M`"%88@$E((T`)1"X`"%8;`$F8,0!(1AB`"9@CP$A6&P!8`&LCQN/`CS"Q@,`
M@L@/`$`I`P"`;P\`W+Q"-"5HN0$E*+@`(6""`2%890$E*(T`)("-`"%@C@$D
M<*,`@L@#`(`O`P`E&-`!:`&NC\+&"P!`>0L`(1B#`24HN0`E8/@!(7#"`2$8
M;``E8*4!)("E`2%PQ`$D8(L!)6"0`2%@C@%P`:Z/PL8#`$!Y`P""R`L`@"<+
M`"%PP@$E()D`)5CX`2%@BP$E6*0`(6C-`2188P&"<`,`@!\#`"3(I``E&&X`
M>`&NC\+&#`!`>0P`)5AY`2%8;0$A<,(!)6CX`2%8;0$E:(,`)("#`"%PQ0$D
M:*P!@L@,`(`O#``E8+`!(6".`8`!KH_"Q@L`0'D+`"4HN0`E:/@!(7#"`2%@
MC0$E:&4`)(!E`"%PQ`$D:*L!@L@+`(`G"P`E6+`!(5AN`8@!KH_"Q@P`0'D,
M`"4@F0`E:/@!(7#"`2%8;0$E:*0`)("D`"%PPP$D:*P!@L@,`(`?#``E8+`!
M(6".`9`!KH_"Q@L`0'D+`"48>0`E:/@!(7#"`2%@C0$E:(,`)("#`"%PQ0$D
M:*L!@L@+`(`O"P`E6+`!(5AN`9@!KH_"Q@P`0'D,`"4HN0`E:/@!(7#"`2%8
M;0$E:&4`)(!E`"%PQ`$D:*P!@L@,`(`G#``E8+`!(6".`:`!KH_"Q@L`0'D+
M`"4@F0`E:/@!(7#"`2%@C0$E:*0`)("D`"%PPP$D:*L!@L@+`(`?"P`E6+`!
M(5AN`:@!KH_"Q@P`0'D,`"48>0`E:/@!(7#"`2%8;0$E:(,`)("#`"%PQ0$D
M:*P!@L@,`(`O#``E8+`!(6".`;`!KH_"Q@L`0'D+`"4HN0`E:/@!(7#"`2%@
MC0$E:&4`)(!E`"%PQ`$D:*L!@L@+`(`G"P`E6+`!(5AN`;@!KH_"Q@P`0'D,
M`"4@F0`E:/@!(7#"`2%8;0$E:*0`)("D`"%PPP$D:*P!@L@,`(`?#``E8+`!
M(6".`<`!KH_"Q@L`0'D+`"48>0`E:/@!(7#"`2%@C0$E:(,`)("#`"%PQ0$D
M:*L!@L@+`(`O"P`E6+`!(5AN`<@!KH_"Q@P`0'D,`"4HN0`E:/@!(7#"`2%8
M;0$E:&4`)(!E`"%PQ`$D:*P!@L@,`(`G#``E8+`!(6".`=`!KH_"Q@L`0'D+
M`"4@F0`E:/@!(7#"`2%@C0$E:*0`)("D`"%PPP$D:*L!@L@+`(`?"P`E6+`!
M(5AN`=@!KH_"Q@P`0'D,`"48>0`E:/@!(7#"`2%8;0$E:(,`)("#`"%PQ0$D
M:*P!@L@,`(`O#``E8+`!(6".`>`!KH_"Q@L`0'D+`"4HN0`E:/@!(7#"`2%@
MC0$E:&4`)(!E`"%PQ`$D:*L!@L@+`(`G"P`E6+`!(5AN`>@!KH_"Q@P`0'D,
M`"4@F0`E:/@!(7#"`2%8;0$E:*0`(7##`22`I``D:*P!)6BP`2%HK@'P`:Z/
MPL8+`$!Y"P""R`P`@!\,`"%PP@$E&'D`)6#X`2%HK`$E8(,`(2C%`23(@P`D
M8(L!)6"9`2%@A0'X`:6/PGX-`$!Q#0""P`L`@%\+`"$0H@`E6'@!)2C/`2%@
MA0$E*&L`(2!$`"0HK0`D$&L`)2BB`"$HI````J2/8LH"/()X#0#6P4(T@&\-
M`"$@@@`E:*\!(2"#`"88;0$F&&P`(2"#``@"HX_"Q@P`0'$,`()X#`"`9PP`
M)7#8`2$88@`A**X`)6"/`2$8:P`F6*P!)EAE`<+&!0"">`4`0'$%`"$8:P"`
M7P4`$`*ECR5PV`$A((X`(2BB`"58;P$A**T`)FB+`29HI`'"Q@0`@G@$`$!Q
M!``A**T`@&\$`!@"I(\E<-@!(1AN`"$@@@`E:*\!(2",`"9@;0$F8(,!PL8#
M`()X`P!`<0,`(2",`(!G`P`@`J./)7#8`2$HK@`A&&(`)6"/`2$8:P`F6*P!
M)EAE`<+&!0"">`4`0'$%`"$8:P"`7P4`*`*ECR5PV`$A((X`(2BB`"58;P$A
M**T`)FB+`29HI`'"Q@0`@G@$`$!Q!``A**T`@&\$`#`"I(\E<-@!(1AN`"$@
M@@`E:*\!(2",`"9@;0$F8(,!PL8#`()X`P!`<0,`(2",`(!G`P`X`J./)7#8
M`2$HK@`A&&(`)6"/`2$8:P`F6*P!)EAE`<+&!0"">`4`0'$%`"$8:P"`7P4`
M0`*ECR5PV`$A((X`(2BB`"58;P$A**T`)FB+`29HI`'"Q@0`@G@$`$!Q!``A
M**T`@&\$`$@"I(\E<-@!(1AN`"$@@@`E:*\!(2",`"9@;0$F8(,!PL8#`()X
M`P!`<0,`(2",`(!G`P!0`J./)7#8`2$HK@`A&&(`)6"/`2$8:P`F6*P!)EAE
M`<+&!0"">`4`0'$%`"$8:P"`7P4`6`*ECR5PV`$A((X`(2BB`"58;P$A**T`
M)FB+`29HI`'"Q@0`@G@$`$!Q!``A**T`@&\$`&`"I(\E<-@!(1AN`"$@@@`E
M:*\!(2",`"9@;0'"Q@,`)F"#`4!Q`P"">`,`(2",`(!G`P!H`J./)7#8`2$H
MK@`A&&(`)6"/`<+&!0!`<04`(1AK`"98K`$E<-@!)EAE`2$@C@"">`4`(1AK
M`(!?!0!P`J6/PL8$`$!Q!``A**(`)5AO`25PV`$A&&X`(2BM`"9PBP$F<,0!
M@G@$`"$HK@"`=P0`>`*DC\+&`P!`:0,`(2""`"5PSP$E:+@!(2BM`"$@C``F
M:&X!)FBC`8)X`P`A((T`@&\#`(`"HX_"Q@4`0&$%`"$88@`E:*\!)6"8`2$8
M:P`F6,T!(2",`"9890$A&&L`B`*KC\+&!`!`800`@G@%`(`O!0`E8)@!(5AB
M`2$8;``E8*\`)BBL`2%8;@$F**0`PL8#`"%890&0`J6/0'$#`()X!``E<-@!
M@"<$`"%P;@&8`JN/(2BB`"4@CP`F>(0!(2BM`"%88@%`:0X`)A#C`<+&#@""
M>`,`(1"B`(`?`P`A*&8!)3"X`2$01@`E&&\`(2BL`"9@@P#"?@(`0%D"`()H
M#@"`-PX`)F".`2$HK``E6&\!)3#-`"$020`A&&@`(2BK``@`(JXA,,<`&``C
MKB$@B@```"6N$``FKB``)*X<`**/I`*CCR0`(*X``$*,#`!B%,P"OX_(`KZ/
MQ`*WC\`"MH^\`K6/N`*TC[0"LX^P`K*/K`*QCZ@"L(\(`.`#T`*])ZB`F8\)
M^"`#``````(`'#P@+YPG(>"9`^#_O2>T@)F/'`"_KQ``O*\)^"`#@``$)$5G
M!#PE*```>`!`K`$CA#0``$2LS>\$/`0`1:PE*```B:N$-`@`1*RZF`0\#`!%
MK"4H``#^W(0T$`!$K#(0!#P4`$6L)2@``'94A#08`$2LTL,$/!P`1:PE,```
M)3@``"4H```H`$:L\.&$-"P`1ZP@`$2L)`!%K#``1JPT`$>L'`"_CP@`X`,@
M`+TG`@`</'`NG"<AX)D#R/^])S``MJ\EL(``+`"UKR6HP``8`+"OP#`&`!``
MO*\E@*``-`"_KR@`M*\D`+.O(`"RKQP`L:\H`(*,+`"(C#``@XPT`(>,(3#"
M`$H``!7#)Q4`*Q#"`$@`0!0!`&(DP$`$`'@`Q8Y"%Q4`*`#&KD(G!``L`,"N
M)1`"`2$80P`A((<`*Q!B`#``PZXA$$0`.`#4)CT`H!0T`,*N0`"B*E$`0!0<
M@)./P/^U)H*)%0!@/7,F`0`R)H"1$@`AD!("0``$)B4H``(E$(`"`P"HB`<`
MIX@+`*:(#P"CB```J)@$`*>8"`"FF`P`HY@0`*4D`P!(J```2+@'`$>H!`!'
MN`L`1J@(`$:X#P!#J`P`0[CN_Z04$`!")"4@P`(ER&`"G/H1!"6`H`#E_Q(6
M$`"\CX")$0`CJ+$"X("9CR4PH`(E*$`""?@@`R4@@`)X`-6N-`"_CS``MH\L
M`+6/*`"TCR0`LX\@`+*/'`"QCQ@`L(\(`.`#.`"])P$`8B0K&$,`(3AG`+;_
M`!`E&$``0``3)."`F8\A((4"(Y!E`B4H``(J$+(""Y"B`@GX(`,E,$`">`#"
MCA``O(\A$$("Y/]3%'@`PJX<@)./)2#``B.HL@)@/7,F)<A@`F[Z$00A@!("
MKO\`$!``O(_3_P`0)9```@(`'#QT+)PG(>"9`\C_O2<P`+6O.`"U)"``L:\E
MB(``'`"PKX#_!"00`+RO)8"@`#0`OZ\L`+2O*`"SKR0`LJ\H`+*,,`"SC,`H
M0GZ@F!-\`0!#)"$0H@*@D!)\.0!E*```1*`"E#(``IPS`%,`H!0A(*,"0``"
M)",00P`$`$,L8`!@$`(`0RQ7`&`0`````%,`0!0`````'("4CV`]E"8ER(`"
M/_H1!"4@``(X``8D$`"\CR4H```L@9F/"?@@`R4@H`(E(``"<``3KB7(@`(T
M^A$$=``2KB4@``(#``*2$`"\CP``(J("``*6%(&9CP$`(J(```*.`A("``(`
M(J(```*.`P`BH@L``I($`"*B"@`"E@4`(J((``*.`A("``8`(J((``*.!P`B
MHA,``I((`"*B$@`"E@D`(J(0``*.`A("``H`(J(0``*."P`BHAL``I(,`"*B
M&@`"E@T`(J(8``*.`A("``X`(J(8``*.#P`BHB,``I(0`"*B(@`"EA$`(J(@
M``*.`A("`!(`(J(@``*.$P`BHC0`OX\P`+6/+`"TCR@`LX\D`+*/(`"QCQP`
ML(\(`"`#.`"])S@`!B0L@9F/)2@```GX(`,C,,,`$`"\CQR`E(^Z_P`08#V4
M)JW_`!```("@_O]")```@*`!`("@J/]`$`(`A"2F_P`0``"`H```@*#\_T(D
M`0"`H`0`A"0"`$,L_O^`H)S_8!3__X"@\?\`$/[_0B0```````````(`'#Q`
M*IPG(>"9`U2`@H\\@9F/"``@`P``1XP`````$("9CR5XX`,)^"`#9@`8)!"`
MF8\E>.`#"?@@`V4`&"00@)F/)7C@`PGX(`-D`!@D$("9CR5XX`,)^"`#8P`8
M)!"`F8\E>.`#"?@@`V(`&"00@)F/)7C@`PGX(`-A`!@D$("9CR5XX`,)^"`#
M8``8)!"`F8\E>.`#"?@@`U\`&"00@)F/)7C@`PGX(`-<`!@D$("9CR5XX`,)
M^"`#6P`8)!"`F8\E>.`#"?@@`UH`&"00@)F/)7C@`PGX(`-9`!@D$("9CR5X
MX`,)^"`#6``8)!"`F8\E>.`#"?@@`U<`&"00@)F/)7C@`PGX(`-6`!@D$("9
MCR5XX`,)^"`#50`8)!"`F8\E>.`#"?@@`U0`&"00@)F/)7C@`PGX(`-3`!@D
M$("9CR5XX`,)^"`#40`8)!"`F8\E>.`#"?@@`U``&"00@)F/)7C@`PGX(`-/
M`!@D$("9CR5XX`,)^"`#30`8)!"`F8\E>.`#"?@@`TP`&"00@)F/)7C@`PGX
M(`-+`!@D$("9CR5XX`,)^"`#2``8)!"`F8\E>.`#"?@@`T<`&"00@)F/)7C@
M`PGX(`-&`!@D$("9CR5XX`,)^"`#0P`8)!"`F8\E>.`#"?@@`T(`&"00@)F/
M)7C@`PGX(`-!`!@D$("9CR5XX`,)^"`#0``8)!"`F8\E>.`#"?@@`S\`&"00
M@)F/)7C@`PGX(`,]`!@D$("9CR5XX`,)^"`#.P`8)!"`F8\E>.`#"?@@`SH`
M&"00@)F/)7C@`PGX(`,Y`!@D$("9CR5XX`,)^"`#.``8)!"`F8\E>.`#"?@@
M`S<`&"00@)F/)7C@`PGX(`,V`!@D$("9CR5XX`,)^"`#-0`8)!"`F8\E>.`#
M"?@@`S0`&"00@)F/)7C@`PGX(`,S`!@D$("9CR5XX`,)^"`#,@`8)!"`F8\E
M>.`#"?@@`S$`&"00@)F/)7C@`PGX(`,P`!@D$("9CR5XX`,)^"`#+P`8)!"`
MF8\E>.`#"?@@`RX`&"00@)F/)7C@`PGX(`,M`!@D$("9CR5XX`,)^"`#+``8
M)!"`F8\E>.`#"?@@`RL`&"00@)F/)7C@`PGX(`,J`!@D$("9CR5XX`,)^"`#
M*``8)!"`F8\E>.`#"?@@`R<`&"00@)F/)7C@`PGX(`,F`!@D$("9CR5XX`,)
M^"`#)0`8)!"`F8\E>.`#"?@@`R0`&"00@)F/)7C@`PGX(`,C`!@D````````
M``````````````(`'#R`)IPG(>"9`^#_O2<0`+RO'`"_KQP`OX\(`.`#(`"]
M)P````````````````$``@`E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA
M3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`
M````+W!R;V,O)6DO)7,`97AE`"X```!005)?5$5-4`````!005)?4%)/1TY!
M344`````.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$52
M3#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`
M4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T=,3T)!
M3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````#$```!,1%],24)2
M05)97U!!5$@`4UE35$5-```O=&UP`````%1%35!$25(`5$U0`%5315(`````
M55-%4DY!344`````)3`R>``````E<R5S)7,E<P````!P87(M`````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H``%!!5$@`````<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E
M<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````8````<&5R;```
M```P````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-3@```!5;F%B;&4@
M=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*`````"UE```M+0``979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?
M;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?
M34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@
M("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-
M04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM
M>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@
M)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@
M+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@
M:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P
M*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK
M7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD
M97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D
M:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP
M(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII
M9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$
M25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)
M6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D
M=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<
M(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@
M97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D
M=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N
M86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q
M6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z
M.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A
M;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH
M/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@
M("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD[
M"E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G
M;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@
M)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P
M<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER
M97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN
M9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S
M*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@
M4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#
M04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD[
M"FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@
M>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*
M?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?
M1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP
M86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)
M3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,
M15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L
M("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H
M92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)
M3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^
M('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E
M;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA
M;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS
M=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@
M)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[
M)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN
M9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H
M)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H
M+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS
M965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*
M)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A
M=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE
M(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR
M97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("10
M2UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%
M('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*
M?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@
M(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U
M;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!
M4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET
M>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H
M"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L
M;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'
M5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD
M14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@
M;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H
M0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ
M*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*
M96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q
M("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I
M('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U
M:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B
M/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D
M(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]
M"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2![
M"F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%2
M1U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70[
M"GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I
M('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q
M6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T
M85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O
M;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS
M.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ
M("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D
M<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I
M;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID
M:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E
M<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I
M(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?
M0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D
M;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY
M("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI
M('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX[
M"GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*
M?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*
M?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER
M92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E
M<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R
M"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO
M?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T
M96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H
M)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF
M("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M
M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D
M97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE
M>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*
M:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D
M,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N
M86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H
M<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E
M9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92![
M"FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT
M(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I
M.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C
M:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L
M($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I
M+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@
M)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z
M:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T
M(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP
M<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE
M7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@
M)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R
M.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N
M9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP
M0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-
M04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A
M:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*
M?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G
M;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N
M($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@
M9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E
M=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E
M861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z
M.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T
M<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A
M8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE
M;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M
M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO
M/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=
M*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE
M(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A
M8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A
M8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@
M=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@
M?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A
M;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"
M=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R
M92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS
M8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A
M<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N
M.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W
M=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U
M<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D
M("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU
M;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE
M7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D
M9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F
M<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A
M9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B
M7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ
M92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@
M/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L
M;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T
M96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B
M)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M
M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N
M=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N
M86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@
M(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D
M=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@
M)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=
M.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E
M;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M
M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92![
M"FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O
M9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P
M<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@
M<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L
M:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D
M<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA
M;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E
M>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92([
M"GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R
M;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_
M($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@
M5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[
M7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS
M=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT[
M"GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6
M>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@
M)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@
M>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U
M<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<
M;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R![
M"G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P
M("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E
M>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O
M<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI
M9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R
M9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D
M<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S
M<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@
M:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`
M.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@```````$-!
M0TA%``!P97)L>'-I+F,`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#`%P``5!<````````````````````````*4$%2+G!M"@``````
M````#%T`````````````````````````````````````````````````@)`3
M```````````"`````0`P.0``Q"(``$@O``#H(P``<"@``,@P```0)P``\%4`
M`"```@`@/```-``"`*0!`@```````````)!9``"`60``<%D``&!9``!060``
M0%D````````P60``(%D``!!9````60``\%@``.!8``#06```P%@``+!8``"@
M6```D%@``(!8``!P6```8%@``%!8``!`6```,%@``"!8````````$%@`````
M````6```\%<``.!7``#05P``P%<`````````````L%<``*!7``"05P``````
M``````"`5P``<%<``&!7````````4%<``$!7```P5P```````"!7```05P``
M`%<``/!6``#@5@``T%8``,!6``"P5@``H%8``)!6`````````````(!6``!P
M5@``8%8``%!6``!`5@``,%8``"!6```05@```````*0!`@!'0T,Z("A$96)I
M86X@,3(N,BXP+3$T*2`Q,BXR+C```.`7`````'^`_/___P``````````.```
M`!T````?````0!D``````X#\____``````````#0````'0```!\```#P&0``
M```?@/S___\``````````.`````=````'P```.P;`````/^`_/___P``````
M````6``!`!T````?````(!X`````'X#\____```````````X$```'0```!\`
M``!0'P````#_@/S___\``````````$@````=````'P````@B``````&`_/__
M_P``````````*````!T````?````C"(`````````````````````````````
M'0```!\```#$(@`````'@/S___\``````````$`@```=````'P```-`C````
M`````````````````````````!T````?````Z",`````_\#\____````````
M````$0``'0```!\```#`)@`````!@/S___\``````````"`````=````'P``
M`!`G``````^`_/___P``````````.!```!T````?````<"@`````_\#\____
M``````````!(````'0```!\```!P+@`````!@/S___\``````````"@````=
M````'P`````O``````"`_/___P``````````(````!T````?````2"\`````
M'X#\____``````````!(````'0```!\```#(,`````#_P/S___\`````````
M`'`!```=````'P```#`Y`````#^`_/___P``````````0````!T````?````
M(#P`````!X#\____```````````P````'0```!\```"0$P`````_@/S___\`
M`````````%`````=````'P```&`]`````/_`_/___P``````````T`(``!T`
M```?````$%$``````(#\____```````````@````'0```!\```#`40````!_
M@/S___\``````````#@````=````'P```+Q3`````#^`_/___P``````````
M.````!T````?````\%4`````````````````````````````'0```!\```!!
M#P```&=N=0`!!P````0%`"YS:'-T<G1A8@`N:6YT97)P`"Y-25!3+F%B:69L
M86=S`"YR96=I;F9O`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G
M`"YD>6YA;6EC`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`
M+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+FEN:70`+G1E>'0`+DU)4%,N<W1U
M8G,`+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?
M87)R87D`+F1A=&$`+G)L9%]M87``+F=O=``N<V1A=&$`+F)S<P`N8V]M;65N
M=``N<&1R`"YG;G4N871T<FEB=71E<P`N;61E8G5G+F%B:3,R````````````
M```````````````````````````````````````````+`````0````(```"4
M`0``E`$```T```````````````$`````````$P```"H``'`"````J`$``*@!
M```8```````````````(````&````"(````&``!P`@```,`!``#``0``&```
M````````````!````!@````K````!P````(```#8`0``V`$``"0`````````
M``````0`````````/@````<````"````_`$``/P!```@```````````````$
M`````````$P````&`````@```!P"```<`@``,`$```D`````````!`````@`
M``!5````!0````(```!,`P``3`,``"@#```(``````````0````$````6P``
M``L````"````=`8``'0&``!P!@``"0````(````$````$````&,````#````
M`@```.0,``#D#```T00``````````````0````````!K````____;P(```"V
M$0``MA$``,X````(``````````(````"````>````/[__V\"````A!(``(02
M``"@````"0````(````$`````````(<````)`````@```"03```D$P``,```
M``@`````````!`````@```"0`````0````8```!4$P``5!,``#P`````````
M``````0`````````E@````$````&````D!,``)`3``"`0@`````````````0
M`````````)P````!````!@```!!6```05@``H`,`````````````!```````
M``"H`````0````8```"P60``L%D``"0```````````````0`````````K@``
M``$````"````X%D``.!9``#`0``````````````0`````````+8````!````
M`@```*":``"@F@``!```````````````!`````````#`````#@````,```#X
M_P$`^/\```0```````````````0````$````S`````\````#````_/\!`/S_
M```$```````````````$````!````-@````!`````P```````@````$`,```
M````````````$`````````#>`````0````,````P``(`,``!``0`````````
M``````0`````````YP````$````#```00``"`$```0!D`0`````````````0
M````!````.P````!`````P``$*0!`@"D`0$`!```````````````!```````
M``#S````"`````,```"P`0(`J`$!`"```````````````!``````````^```
M``$````P`````````*@!`0`?```````````````!`````0````$!```!````
M``````````#(`0$`0`,`````````````!``````````&`0``]?__;P``````
M````"`4!`!````````````````$`````````%@$```$``````````````!@%
M`0`````````````````!``````````$````#```````````````8!0$`)`$`
1`````````````0``````````
